@@ -40,6 +40,8 @@ def train_model_task(
     pj: PredictionJobDataClass,
     context: TaskContext,
     check_old_model_age: bool = DEFAULT_CHECK_MODEL_AGE,
+    datetime_start: datetime = None,
+    datetime_end: datetime = None,
 ) -> None:
     """Train model task.
 
@@ -61,8 +63,10 @@ def train_model_task(
     context.perf_meter.checkpoint("Added metadata to PredictionJob")
 
     # Define start and end of the training input data
-    datetime_start = datetime.utcnow() - timedelta(days=TRAINING_PERIOD_DAYS)
-    datetime_end = datetime.utcnow()
+    if datetime_end is None:
+        datetime_end = datetime.utcnow()
+    if datetime_start is None:
+        datetime_start = datetime_end - timedelta(days=TRAINING_PERIOD_DAYS)
 
     # todo: See if we can check model age before getting the data
     # Get training input data from database
@@ -97,8 +101,11 @@ def main(model_type=None, config=None, database=None):
         model_type = [ml.value for ml in MLModelType]
 
     taskname = Path(__file__).name.replace(".py", "")
+    datetime_now = datetime.utcnow()
     with TaskContext(taskname, config, database) as context:
-        PredictionJobLoop(context, model_type=model_type).map(train_model_task, context)
+        PredictionJobLoop(context, model_type=model_type).map(
+            train_model_task, context, timedate_end=datetime_now
+        )
 
 
 if __name__ == "__main__":
