@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2017-2021 Contributors to the OpenSTF project <korte.termijn.prognoses@alliander.com> # noqa E501>
+# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
 
@@ -10,7 +10,6 @@ import pandas as pd
 import structlog
 
 from openstef.preprocessing.preprocessing import (
-    replace_invalid_data,
     replace_repeated_values_with_nan,
 )
 
@@ -27,8 +26,27 @@ def validate(
     data: pd.DataFrame,
     flatliner_threshold: int = FLATLINER_TRESHOLD,
 ) -> pd.DataFrame:
-    """Validate prediction job and timeseries data."""
+    """Validate prediction job and timeseries data.
+    Steps:
+    1. Replace repeated values for longer than flatliner_threshold with NaN
+    # TODO: The function description suggests it
+    'validates' the PJ and Data, but is appears to 'just' replace repeated observations with NaN.
+
+    Args:
+        - pj_id: ind/str, used to identify log statements
+        - data: pd.DataFrame where the first column should be the target. index=datetimeIndex
+        - flatliner_threshold: int of max repetitions considered a flatline.
+            if None, the validation is effectively skipped
+
+    Returns:
+        Dataframe where repeated values are set to None"""
+
     logger = structlog.get_logger(__name__)
+
+    if flatliner_threshold is None:
+        logger.info("Skipping validation of input data", pj_id=pj_id)
+        return data
+
     # Drop 'false' measurements. e.g. where load appears to be constant.
     data = replace_repeated_values_with_nan(
         data, max_length=flatliner_threshold, column_name=data.columns[0]
@@ -36,50 +54,30 @@ def validate(
     num_repeated_values = len(data) - len(data.iloc[:, 0].dropna())
     if num_repeated_values > 0:
         frac_const_load_values = num_repeated_values / len(data.index)
-    else:
-        frac_const_load_values = 0.0
-    logger.warning(
-        f"Found {num_repeated_values} values of constant load (repeated values), converted to NaN value.",
-        cleansing_step="repeated_values",
-        pj_id=pj_id,
-        num_values=num_repeated_values,
-        frac_values=frac_const_load_values,
-    )
 
-    # Check for repeated load observations due to invalid measurements
-    nonzero_flatliners = find_nonzero_flatliner(data, threshold=flatliner_threshold)
-    if nonzero_flatliners is not None:
-        # Covert repeated load observations to NaN values
-        data = replace_invalid_data(data, nonzero_flatliners)
-        # Calculate number of NaN values
-        # TODO should this not be part of the replace_invalid_data function?
-        num_nan_values = sum([True for i, row in data.iterrows() if all(row.isnull())])
-        frac_nan_values = num_nan_values / len(data.index)
-    else:
-        num_nan_values = 0
-        frac_nan_values = 0.0
-    logger.warning(
-        f"Found {num_nan_values} nonzero flatliner data points, converted to NaN value.",
-        cleansing_step="nonzero_flatliner_data_points",
-        pj_id=pj_id,
-        num_values=num_nan_values,
-        frac_values=frac_nan_values,
-    )
+        logger.info(
+            f"Found {num_repeated_values} values of constant load (repeated values), converted to NaN value.",
+            cleansing_step="repeated_values",
+            pj_id=pj_id,
+            num_values=num_repeated_values,
+            frac_values=frac_const_load_values,
+        )
+
     return data
 
 
 def clean(data: pd.DataFrame) -> pd.DataFrame:
     logger = structlog.get_logger(__name__)
-    data = data[data.index.min() + timedelta(weeks=2) :]
     len_original = len(data)
-    # TODO Look into this
-    # Remove where load is NA # # df.dropna?
+    # Remove where load is NA, NaN features are preserved
     data = data.loc[np.isnan(data.iloc[:, 0]) != True, :]  # noqa E712
     num_removed_values = len_original - len(data)
-    logger.debug(
-        f"Removed {num_removed_values} NaN values",
-        num_removed_values=num_removed_values,
-    )
+    if num_removed_values > 0:
+        logger.info(
+            f"Removed {num_removed_values} NaN values",
+            num_removed_values=num_removed_values,
+        )
+
     return data
 
 
@@ -191,13 +189,14 @@ def calc_completeness(
     return completeness
 
 
-def find_nonzero_flatliner(df: pd.DataFrame, threshold: int) -> pd.DataFrame:
+def find_nonzero_flatliner(df: pd.DataFrame, threshold: int = None) -> pd.DataFrame:
     """Function that detects a stationflatliner and returns a list of datetimes.
 
     Args:
         df: pd.dataFrame(index=DatetimeIndex, columns = [load1, ..., loadN]).
             Load_corrections should be indicated by 'LC_'
         threshold: after how many timesteps should the function detect a flatliner.
+            If None, the check is not executed
 
     Returns:
     # TODO: function returns None or a DataFrame
